@@ -1,10 +1,9 @@
 /*
  * Copyright (C) 2019 Purism SPC
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#define HANDY_USE_UNSTABLE_API
 #include <handy.h>
 
 
@@ -18,7 +17,7 @@ test_hdy_preferences_window_add (void)
   window = g_object_ref_sink (HDY_PREFERENCES_WINDOW (hdy_preferences_window_new ()));
   g_assert_nonnull (window);
 
-  page = hdy_preferences_page_new ();
+  page = HDY_PREFERENCES_PAGE (hdy_preferences_page_new ());
   g_assert_nonnull (page);
   gtk_container_add (GTK_CONTAINER (window), GTK_WIDGET (page));
 
@@ -35,7 +34,7 @@ main (gint argc,
       gchar *argv[])
 {
   gtk_test_init (&argc, &argv, NULL);
-  hdy_init (&argc, &argv);
+  hdy_init ();
 
   g_test_add_func("/Handy/PreferencesWindow/add", test_hdy_preferences_window_add);
 
